==> plasma-workspace-5.27.10-2.2.src.tar.gz: plasma-workspace-5.27.10/shell/org.kde.plasmashell.desktop.cmake <==
[Desktop Entry]
Exec=@CMAKE_INSTALL_PREFIX@/bin/plasmashell
X-DBUS-StartupType=Unique
Name=Plasma Desktop Workspace
Name[ar]=مساحة عمل سطح مكتب بلازما
Name[az]=Plasma İş masası Mühiti
Name[be]=Працоўныя прасторы Plasma
Name[bg]=Работен плот на Plasma
Name[bs]=Radni prostor plazma radne površi
Name[ca]=Espai de treball de l'escriptori Plasma
Name[ca@valencia]=Espai de treball de l'escriptori Plasma
Name[cs]=Pracovní plocha Plasma
Name[da]=Plasma Desktop Workspace
Name[de]=Plasma-Arbeitsflächenbereich
Name[el]=Χώρος επιφάνειας εργασίας Plasma
Name[en_GB]=Plasma Desktop Workspace
Name[eo]=Plasma Fenestrila Laborspaco
Name[es]=Espacio de trabajo del escritorio Plasma
Name[et]=Plasma töölaua töötsoon
Name[eu]=Plasma mahaigainaren lanerako guneak
Name[fi]=Plasma-työpöytä
Name[fr]=Espace de travail Plasma
Name[ga]=Spás Oibre Deisce Plasma
Name[gl]=Espazo de traballo do escritorio Plasma
Name[he]=תחנת עבודה של שולחן העבודה Plasma
Name[hi]=प्लाज़्मा डेस्कटॉप कार्यक्षेत्र
Name[hr]=Plasma radno okruženje
Name[hsb]=Plasma-dźěłowy rum z dźěłowym powjerchom
Name[hu]=Plazma asztali munkaterület
Name[ia]=Spatio de labor de scriptorio de Plasma
Name[id]=Ruangkerja Desktop Plasma
Name[is]=Vinnusvæði Plasma
Name[it]=Spazio di lavoro del desktop di Plasma
Name[ja]=Plasma デスクトップワークスペース
Name[ka]=Plasma Desktop Workspace
Name[ko]=Plasma 데스크톱 작업 공간
Name[lt]=Plasma darbalaukio darbo sritis
Name[ml]=പ്ലാസ്മ ഡെസ്ക്ടോപ്പ് പണിയിടം
Name[nb]=Arbeidsrom for Plasma skrivebord
Name[nds]=Plasma-Schriefdischarbeitrebeet
Name[nl]=Plasma Bureaublad Werkplek
Name[nn]=Arbeidsområde for Plasma-skrivebord
Name[pa]=ਪਲਾਜ਼ਮਾ ਡੈਸਕਟਾਪ ਵਰਕਸਪੇਸ
Name[pl]=Przestrzeń Pracy Pulpitu Plazmy
Name[pt]=Área de Trabalho do Plasma
Name[pt_BR]=Espaço de Trabalho Plasma
Name[ro]=Spațiu de lucru al biroului Plasma
Name[ru]=Рабочая среда Plasma
Name[sk]=Pracovná plocha Plasma
Name[sl]=Delovni prostor Plasma Desktop
Name[sr]=Плазма, радни простор површи
Name[sr@ijekavian]=Плазма, радни простор површи
Name[sr@ijekavianlatin]=Plasma, radni prostor površi
Name[sr@latin]=Plasma, radni prostor površi
Name[sv]=Plasma arbetsområde för skrivbordet
Name[ta]=பிளாஸ்மா பணிமேடை
Name[tg]=Фазои мизи кории Плазма
Name[tr]=Plasma Masaüstü Çalışma Alanı
Name[uk]=Робочий простір Плазми для комп’ютерів
Name[vi]=Không gian bàn làm việc Plasma
Name[x-test]=xxPlasma Desktop Workspacexx
Name[zh_CN]=Plasma 桌面工作空间
Name[zh_TW]=Plasma 桌面工作空間
Type=Application
X-KDE-StartupNotify=false
X-DBUS-ServiceName=org.kde.plasmashell
OnlyShowIn=KDE;
X-KDE-autostart-phase=0
Icon=plasmashell
NoDisplay=true
X-systemd-skip=true

X-KDE-Wayland-Interfaces=org_kde_plasma_window_management,org_kde_kwin_keystate,zkde_screencast_unstable_v1,org_kde_plasma_activation_feedback
X-KDE-DBUS-Restricted-Interfaces=org.kde.kwin.Screenshot,org.kde.KWin.ScreenShot2

==> plasma-workspace-6.2.5-1.1.src.tar.gz: plasma-workspace-6.2.5/shell/org.kde.plasmashell.desktop.cmake <==
[Desktop Entry]
Exec=@CMAKE_INSTALL_PREFIX@/bin/plasmashell
X-DBUS-StartupType=Unique
Name=Plasma Desktop Workspace
Name[ar]=مساحة عمل سطح مكتب بلازما
Name[az]=Plasma İş masası Mühiti
Name[be]=Працоўныя прасторы Plasma
Name[bg]=Работен плот на Plasma
Name[bs]=Radni prostor plazma radne površi
Name[ca]=Espai de treball de l'escriptori Plasma
Name[ca@valencia]=Espai de treball de l'escriptori Plasma
Name[cs]=Pracovní plocha Plasma
Name[da]=Plasma Desktop Workspace
Name[de]=Plasma-Arbeitsflächenbereich
Name[el]=Χώρος επιφάνειας εργασίας Plasma
Name[en_GB]=Plasma Desktop Workspace
Name[eo]=Plasma Fenestrila Laborspaco
Name[es]=Espacio de trabajo del escritorio Plasma
Name[et]=Plasma töölaua töötsoon
Name[eu]=Plasma mahaigainaren lanerako guneak
Name[fa]=محل‌کار میزکار پلاسما
Name[fi]=Plasma-työpöytä
Name[fr]=Espace de travail Plasma
Name[ga]=Spás Oibre Deisce Plasma
Name[gl]=Espazo de traballo do escritorio Plasma
Name[he]=מרחב שולחן העבודה פלזמה
Name[hi]=प्लाज़्मा डेस्कटॉप कार्यक्षेत्र
Name[hr]=Plasma radno okruženje
Name[hsb]=Plasma-dźěłowy rum z dźěłowym powjerchom
Name[hu]=Plasma asztali munkaterület
Name[ia]=Spatio de labor de scriptorio de Plasma
Name[id]=Ruangkerja Desktop Plasma
Name[is]=Vinnusvæði Plasma
Name[it]=Spazio di lavoro del desktop di Plasma
Name[ja]=Plasma デスクトップワークスペース
Name[ka]=Plasma Desktop Workspace
Name[ko]=Plasma 데스크톱 작업 공간
Name[lt]=Plasma darbalaukio darbo sritis
Name[lv]=„Plasma“ darbvirsma
Name[ml]=പ്ലാസ്മ ഡെസ്ക്ടോപ്പ് പണിയിടം
Name[nb]=Arbeidsrom for Plasma skrivebord
Name[nds]=Plasma-Schriefdischarbeitrebeet
Name[nl]=Plasma Bureaublad Werkplek
Name[nn]=Arbeidsområde for Plasma-skrivebord
Name[pa]=ਪਲਾਜ਼ਮਾ ਡੈਸਕਟਾਪ ਵਰਕਸਪੇਸ
Name[pl]=Przestrzeń Pracy Pulpitu Plazmy
Name[pt]=Área de Trabalho do Plasma
Name[pt_BR]=Espaço de Trabalho Plasma
Name[ro]=Spațiu de lucru al biroului Plasma
Name[ru]=Рабочая среда Plasma
Name[sa]=प्लाज्मा कार्यमुखम् कार्यक्षेत्र
Name[sk]=Pracovná plocha Plasma
Name[sl]=Delovni prostor Plasma Desktop
Name[sr]=Плазма, радни простор површи
Name[sr@ijekavian]=Плазма, радни простор површи
Name[sr@ijekavianlatin]=Plasma, radni prostor površi
Name[sr@latin]=Plasma, radni prostor površi
Name[sv]=Plasma arbetsområde för skrivbordet
Name[ta]=பிளாஸ்மா பணிமேடை
Name[tg]=Фазои мизи кории Плазма
Name[tr]=Plasma Masaüstü Çalışma Alanı
Name[uk]=Робочий простір Плазми для комп’ютерів
Name[vi]=Không gian bàn làm việc Plasma
Name[x-test]=xxPlasma Desktop Workspacexx
Name[zh_CN]=Plasma 桌面工作空间
Name[zh_TW]=Plasma 桌面工作空間
Type=Application
StartupNotify=false
X-DBUS-ServiceName=org.kde.plasmashell
OnlyShowIn=KDE;
X-KDE-autostart-phase=0
Icon=plasmashell
NoDisplay=true
X-systemd-skip=true

X-KDE-Wayland-Interfaces=org_kde_plasma_window_management,org_kde_kwin_keystate,zkde_screencast_unstable_v1,org_kde_plasma_activation_feedback
X-KDE-DBUS-Restricted-Interfaces=org.kde.KWin.ScreenShot2
